UpdateRate

Enum UpdateRate 

pub enum UpdateRate {
    Native,
    Max(u32),
}
Update rate for telemetry streams

Variants



Native

Full speed from source (typically 60Hz)



Max(u32)

Throttled to maximum Hz If the requested rate exceeds source rate, Native is used

Implementations

Source

impl UpdateRate

pub fn normalize(self, source_hz: f64) -> UpdateRate

Normalize rate against source frequency Returns effective rate to use

pub fn needs_throttle(self, source_hz: f64) -> bool

Check if throttling is needed

pub fn throttle_interval(self, source_hz: f64) -> Option<Duration>

Get throttle interval if needed