pub enum UpdateRate {
Native,
Max(u32),
}Expand description
Update rate for telemetry streams
Variants
Native
Full speed from source (typically 60Hz)
Max(u32)
Throttled to maximum Hz If the requested rate exceeds source rate, Native is used
Implementations
Sourceimpl UpdateRate
impl UpdateRate
Sourcepub fn normalize(self, source_hz: f64) -> UpdateRate
pub fn normalize(self, source_hz: f64) -> UpdateRate
Normalize rate against source frequency Returns effective rate to use
Sourcepub fn needs_throttle(self, source_hz: f64) -> bool
pub fn needs_throttle(self, source_hz: f64) -> bool
Check if throttling is needed
Sourcepub fn throttle_interval(self, source_hz: f64) -> Option<Duration>
pub fn throttle_interval(self, source_hz: f64) -> Option<Duration>
Get throttle interval if needed